@@ -11,12 +11,6 @@ from odoo_env.images import Image, Image2
 
 
 class TestRepository(unittest.TestCase):
-    def setUp(self, *args, **kwargs):
-        super().setUp(*args, **kwargs)
-
-        conf = OeConfig()
-        conf.unlink()
-        conf._test = True
 
     def test_install(self):
         """ ################################################# TEST INSTALLATION
@@ -335,7 +329,7 @@ class TestRepository(unittest.TestCase):
             '-b 9.0 https://github.com/ingadhoc/odoo-argentina.git adhoc-odoo-argentina')
         self.assertEqual(
             cmds[18].usr_msg,
-            'cloning b 9.0     https://github.com/ingadhoc/odoo-argentina.git adhoc-odoo-argentina')
+            'cloning b 9.0     https://github.com/ingadhoc/odoo-argentina.git >> adhoc-odoo-argentina')
 
         self.assertEqual(
             cmds[19].args,
@@ -345,7 +339,7 @@ class TestRepository(unittest.TestCase):
             'git -C /odoo_ar/odoo-9.0/test2_client/sources/adhoc-odoo-argentina pull')
         self.assertEqual(
             cmds[19].usr_msg,
-            'pulling b 9.0     https://github.com/ingadhoc/odoo-argentina.git adhoc-odoo-argentina')
+            'pulling b 9.0     https://github.com/ingadhoc/odoo-argentina.git >> adhoc-odoo-argentina')
 
     def test_install2_enterprise(self):
         """ ################################### TEST INSTALLATION v2 ENTERPRISE
@@ -354,6 +348,7 @@ class TestRepository(unittest.TestCase):
             'debug': True,
             'no-repos': False,
             'nginx': True,
+            'extract_sources': False,
         }
 
         base_dir = '/odoo_ar/'
@@ -511,7 +506,7 @@ class TestRepository(unittest.TestCase):
             '-v /odoo_ar/odoo-9.0/dist-packages:' \
             '/usr/lib/python2.7/dist-packages ' \
             '-v /odoo_ar/odoo-9.0/dist-local-packages:' \
-            '/usr/local/lib/python2.7/dist-local-packages ' \
+            '/usr/local/lib/python2.7/dist-packages ' \
             '--link pg-test_client:db ' \
             '--name test_client ' \
             '-e ODOO_CONF=/dev/null ' \
@@ -589,7 +584,7 @@ class TestRepository(unittest.TestCase):
         database = 'client_prod'
         backup_file = 'bkp.zip'
         oe = OdooEnv(options)
-        cmds = oe.restore(client_name, database, backup_file, deactivate=True)
+        cmds = oe.restore(client_name, database, backup_file, no_deactivate=False)
         command = \
             'sudo docker run --rm -i ' \
             '--link pg-test_client:db ' \
@@ -598,7 +593,7 @@ class TestRepository(unittest.TestCase):
             '--env NEW_DBNAME=client_prod ' \
             '--env ZIPFILE=bkp.zip ' \
             '--env DEACTIVATE=True ' \
-            'jobiols/dbtools '
+            'jobiols/dbtools:1.2.0 '
 
         self.assertEqual(cmds[0].command, command)
 
@@ -609,6 +604,7 @@ class TestRepository(unittest.TestCase):
             'debug': True,
             'no-repos': False,
             'nginx': False,
+            'extract_sources': True,
         }
         oe = OdooEnv(options)
         cmds = oe.install('test_client')
@@ -752,19 +748,6 @@ class TestRepository(unittest.TestCase):
                   'pull'
         self.assertEqual(cmds[39].command, command)
 
-    def test_config(self):
-        """ ####################################################### TEST CONFIG
-        """
-        OeConfig().unlink()
-
-        path = OeConfig().get_client_path('test_client')
-        self.assertFalse(path)
-
-        OeConfig().save_client_path('test_client',
-                                    '/odoo_ar/odoo-9.0/test_client')
-        path = OeConfig().get_client_path('test_client')
-        self.assertEqual(path, '/odoo_ar/odoo-9.0/test_client')
-
     def test_check_version(self):
         """ ##################################################### CHECK VERSION
         """
@@ -774,16 +757,17 @@ class TestRepository(unittest.TestCase):
         """ ##################################################### CHECK VERSION
         """
         env = OeConfig().get_environment()
+        OeConfig().save_environment('prod')
+        env = OeConfig().get_environment()
         self.assertEqual(env, 'prod')
         OeConfig().save_environment('debug')
         env = OeConfig().get_environment()
         self.assertEqual(env, 'debug')
 
     def test_save_multiple_clients(self):
-        OeConfig().save_client_path('test_client', 'multiple_path')
-        OeConfig().save_client_path('test_client', 'multiple_path')
-        config = OeConfig().get_config_data()
-        self.assertEqual(len(config.get('clients')), 1)
+        OeConfig().save_client_path('test_clientx', 'multiple_path1')
+        OeConfig().save_client_path('test_clientx', 'multiple_path2')
+        self.assertEqual(OeConfig().get_client_path('test_clientx'), 'multiple_path1')
 
     def test_repo_clone(self):
         repo = Repo({'usr': 'jobiols', 'repo': 'project', 'branch': '9.0'})
@@ -791,13 +775,40 @@ class TestRepository(unittest.TestCase):
 
     def test_repo2_clone(self):
         repo = Repo2('https://github.com/jobiols/project.git', '9.0')
+        self.assertEqual(repo.dir_name, 'project')
+        self.assertEqual(repo.branch, '9.0')
+        self.assertEqual(repo.url, 'https://github.com/jobiols/project.git')
+        self.assertEqual(repo.formatted, 'b 9.0     https://github.com/jobiols/project.git')
         self.assertEqual(repo.clone, 'clone --depth 1 -b 9.0 https://github.com/jobiols/project.git')
         self.assertEqual(repo.pull, 'pull')
+
+    def test_repo2_clone_branch(self):
+        repo = Repo2('https://github.com/jobiols/project.git -b 9.0', '8.0')
         self.assertEqual(repo.dir_name, 'project')
+        self.assertEqual(repo.branch, '9.0')
+        self.assertEqual(repo.url, 'https://github.com/jobiols/project.git')
+        self.assertEqual(repo.formatted, 'b 9.0     https://github.com/jobiols/project.git')
+        self.assertEqual(repo.clone, 'clone --depth 1 -b 9.0 https://github.com/jobiols/project.git')
+        self.assertEqual(repo.pull, 'pull')
 
     def test_repo2_clone_dir(self):
         repo = Repo2('https://github.com/jobiols/project.git adhoc-project', '9.0')
         self.assertEqual(repo.dir_name, 'adhoc-project')
+        self.assertEqual(repo.branch, '9.0')
+        self.assertEqual(repo.url, 'https://github.com/jobiols/project.git adhoc-project')
+        self.assertEqual(repo.formatted, 'b 9.0     https://github.com/jobiols/project.git >> adhoc-project')
+        self.assertEqual(repo.clone, 'clone --depth 1 -b 9.0 https://github.com/jobiols/project.git adhoc-project')
+        self.assertEqual(repo.pull, 'pull')
+
+    def test_repo2_clone_branch_dir(self):
+        repo = Repo2('https://github.com/jobiols/project.git adhoc-project -b 9.0', '8.0')
+        self.assertEqual(repo.dir_name, 'adhoc-project')
+        self.assertEqual(repo.branch, '9.0')
+        self.assertEqual(repo.url, 'https://github.com/jobiols/project.git adhoc-project')
+        self.assertEqual(repo.formatted, 'b 9.0     https://github.com/jobiols/project.git >> adhoc-project')
+        self.assertEqual(repo.clone, 'clone --depth 1 -b 9.0 https://github.com/jobiols/project.git adhoc-project')
+        self.assertEqual(repo.pull, 'pull')
+
 
     def test_image(self):
         image = Image({'name': 'odoo', 'usr': 'jobiols', 'img': 'odoo-jeo', 'ver': '9.0'})
